@@ -1,6 +1,6 @@
 module SpecInfra
   module Helper
-    ['Exec', 'Ssh', 'Cmd', 'WinRM', 'ShellScript', 'Dockerfile'].each do |type|
+    ['Exec', 'Ssh', 'Cmd', 'Docker', 'WinRM', 'ShellScript', 'Dockerfile', 'Lxc'].each do |type|
       eval <<-EOF
         module #{type}
           def backend(commands_object=nil)
